cargo-sym-0.0.2 is not a library.
cargo-sym
Prints various binary symbols in your crate
Usage
First install:
cargo install cargo-sym
Then:
cargo symwill print every debugging symbol it finds in the first valid binary target intarget/debugcargo sym -dwill print every debugging symbol demangledcargo sym -ewill print every exported symbol importable by other binariescargo sym -e -dwill do-dand-etogether :]
TODO:
When goblin gets a mach and PE backend (which should be soonish), will update here
PRs welcome of course :)